@@ -3,6 +3,7 @@
 package org.hamcrest;
 
 import junit.framework.TestCase;
+import org.junit.Assert;
 
 public abstract class AbstractMatcherTest extends TestCase {
 
@@ -10,22 +11,26 @@ public abstract class AbstractMatcherTest extends TestCase {
      * Create an instance of the Matcher so some generic safety-net tests can be run on it.
      */
     protected abstract Matcher<?> createMatcher();
-
-    protected static final Object ARGUMENT_IGNORED = new Object();
-    protected static final Object ANY_NON_NULL_ARGUMENT = new Object();
-
-    public <T> void assertMatches(String message, Matcher<T> c, T arg) {
-        assertTrue(message, c.matches(arg));
+    
+    public static <T> void assertMatches(String message, Matcher<? super T> c, T arg) {
+        Assert.assertTrue(message, c.matches(arg));
     }
 
-    public <T> void assertDoesNotMatch(String message, Matcher<T> c, T arg) {
-        assertFalse(message, c.matches(arg));
+    public static <T> void assertDoesNotMatch(String message, Matcher<? super T> c, T arg) {
+        Assert.assertFalse(message, c.matches(arg));
     }
 
-    public void assertDescription(String expected, Matcher matcher) {
+    public static void assertDescription(String expected, Matcher<?> matcher) {
         Description description = new StringDescription();
         description.appendDescriptionOf(matcher);
-        assertEquals(expected, description.toString());
+        Assert.assertEquals("Expected description", expected, description.toString().trim());
+    }
+
+    public static <T> void assertMismatchDescription(String expected, Matcher<? super T> matcher, T arg) {
+        Assert.assertFalse("Precondtion: Matcher should not match item.", matcher.matches(arg));
+        Description description = new StringDescription();
+        matcher.describeMismatch(arg, description);
+        Assert.assertEquals("Expected mismatch description", expected, description.toString().trim());
     }
 
     public void testIsNullSafe() {
