@@ -5,11 +5,13 @@ import junit.framework.TestCase;
 public class BaseMatcherTest extends TestCase {
 
     public void testDescribesItselfWithToStringMethod() {
-        Matcher someMatcher = new BaseMatcher() {
+        Matcher<Object> someMatcher = new BaseMatcher<Object>() {
+            @Override
             public boolean matches(Object item) {
                 throw new UnsupportedOperationException();
             }
 
+            @Override
             public void describeTo(Description description) {
                 description.appendText("SOME DESCRIPTION");
             }
