@@ -19,11 +19,13 @@ public class EasyMock2AdapterTest extends TestCase {
     }
 
     public void testDelegatesDescriptionToUnderlyingMatcher() {
-        IArgumentMatcher easyMockMatcher = new EasyMock2Adapter(new BaseMatcher() {
+        IArgumentMatcher easyMockMatcher = new EasyMock2Adapter(new BaseMatcher<Object>() {
+            @Override
             public boolean matches(Object o) {
                 return false;
             }
 
+            @Override
             public void describeTo(Description description) {
                 description.appendText("is like ");
                 description.appendValue("cheese");
