@@ -2,16 +2,17 @@
  */
 package org.hamcrest.text;
 
-import static org.hamcrest.text.StringContains.containsString;
+import static org.hamcrest.core.StringContains.containsString;
+
 import org.hamcrest.AbstractMatcherTest;
 import org.hamcrest.Matcher;
 
 
 public class StringContainsTest extends AbstractMatcherTest {
     static final String EXCERPT = "EXCERPT";
-
     Matcher<String> stringContains = containsString(EXCERPT);
 
+    @Override
     protected Matcher<?> createMatcher() {
         return stringContains;
     }
@@ -36,4 +37,8 @@ public class StringContainsTest extends AbstractMatcherTest {
         assertTrue("should be true if excerpt is entire string",
                 stringContains.matches(EXCERPT));
     }
+
+    public void testHasAReadableDescription() {
+        assertDescription("a string containing \"EXCERPT\"", stringContains);
+    }
 }
